@@ -294,7 +294,7 @@ tconv_t tconv_open_ext(const char *tocodes, const char *fromcodes, tconv_option_
   /* 1. trace */
   traces                       = getenv(TCONV_ENV_TRACE);
   tconvp->traceb               = (traces != NULL) ? (atoi(traces) != 0 ? 1 : 0) : 0;
-  if (tconvOptionp != NULL) {
+  if ((tconvOptionp != NULL) && (tconvp->traceCallbackp != NULL)) {
     tconvp->traceCallbackp  = tconvOptionp->traceCallbackp;
     tconvp->traceUserDatavp = tconvOptionp->traceUserDatavp;
     tconvp->genericLoggerp  = genericLogger_newp(_tconvTraceCallbackProxy, tconvp, GENERICLOGGER_LOGLEVEL_TRACE);
@@ -734,7 +734,7 @@ static inline short _tconvDefaultCharsetOption(tconv_t tconvp, tconv_charset_ext
   return 1;
 
  err:
-  TCONV_TRACE(tconvp, "%s - character converter %s is not available", funcs);
+  TCONV_TRACE(tconvp, "%s - character converter %s is not available", funcs, converts);
   errno = ENOSYS;
   return 0;
 }
@@ -745,9 +745,8 @@ static inline void _tconvTraceCallbackProxy(void *userDatavp, genericLoggerLevel
 {
   tconv_t tconvp = (tconv_t) userDatavp;
 
-  if (tconvp->traceCallbackp != NULL) {
-    tconvp->traceCallbackp(tconvp->traceUserDatavp, msgs);
-  }
+  /* By definition _tconvTraceCallbackProxy is called only if tconvp->traceCallbackp is != NULL */
+  tconvp->traceCallbackp(tconvp->traceUserDatavp, msgs);
 }
 
 /****************************************************************************/
